==> langworks-0.1.0-py3-none-any.whl: langworks/__init__.py <==
# Stub# ##################################################################################################
#
# Title:
#
#   langworks.__init__.py
#
# License:
#
#   Copyright 2025 Rosaia B.V.
#
#   Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except 
#   in compliance with the License. You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software distributed under the 
#   License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
#   express or implied. See the License for the specific language governing permissions and 
#   limitations under the License.
#
#   [Apache License, version 2.0]
#
# Description: 
#
#   Part of the Langworks framework, being the initializing script of the framework.
#
# ##################################################################################################

# ##################################################################################################
# Imports
# ##################################################################################################

# Third party ######################################################################################

# pypeworks (Rosaia)
from pypeworks import (
    Connection
)


# Local ############################################################################################

# Langwork
from .langwork import (
    Langwork
)

# Query
from .query import (
    Query
)


# End of File ######################################################################################

==> langworks-0.2.0-py3-none-any.whl: langworks/__init__.py <==
# Stub# ##################################################################################################
#
# Title:
#
#   langworks.__init__.py
#
# License:
#
#   Copyright 2025 Rosaia B.V.
#
#   Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except 
#   in compliance with the License. You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software distributed under the 
#   License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
#   express or implied. See the License for the specific language governing permissions and 
#   limitations under the License.
#
#   [Apache License, version 2.0]
#
# Description: 
#
#   Part of the Langworks framework, being the initializing script of the framework.
#
# ##################################################################################################

# ##################################################################################################
# Imports
# ##################################################################################################

# Third party ######################################################################################

# pypeworks (Rosaia)
from pypeworks import (
    Connection
)


# Local ############################################################################################

# Langwork
from langworks.langwork import (
    Langwork
)

# Query
from langworks.query import (
    Query
)


# End of File ######################################################################################
